==> vipps_recurring_payments-8.x-2.2-beta2.tar.gz: vipps_recurring_payments/src/Factory/RequestStorageFactory.php <==
<?php

declare(strict_types=1);

namespace Drupal\vipps_recurring_payments\Factory;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\vipps_recurring_payments\Form\SettingsForm;
use Drupal\vipps_recurring_payments\RequestStorage\CancelAgreement;
use Drupal\vipps_recurring_payments\RequestStorage\CreateChargeData;
use Drupal\vipps_recurring_payments\RequestStorage\DraftAgreementData;
use Drupal\vipps_recurring_payments\RequestStorage\RequestStorageInterface;
use Drupal\vipps_recurring_payments\Service\DelayManager;
use Drupal\vipps_recurring_payments\Service\VippsApiConfig;
use Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface;
use Detection\MobileDetect;

/**
 * Request Storage Factory.
 */
class RequestStorageFactory {

  /**
   * Vipps Api Config.
   *
   * @var \Drupal\vipps_recurring_payments\Service\VippsApiConfig
   */
  protected $vippsApiConfig;

  /**
   * Configurations.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Delay Manager.
   *
   * @var \Drupal\vipps_recurring_payments\Service\DelayManager
   */
  protected $delayManager;

  /**
   * Mobile detect.
   *
   * @var Mobile_Detect
   */
  private $mobileDetect;

  /**
   * Construct.
   */
  public function __construct(
    VippsApiConfig $vippsApiConfig,
    ConfigFactoryInterface $configFactory,
    DelayManager $delayManager,
    MobileDetect $mobile_detect
  ) {
    $this->vippsApiConfig = $vippsApiConfig;
    $this->config = $configFactory->getEditable(SettingsForm::SETTINGS);
    $this->delayManager = $delayManager;
    $this->mobileDetect = $mobile_detect;
  }

  /**
   * Build the default Agreement data.
   */
  public function buildDefaultDraftAgreement(
    ProductSubscriptionInterface $product,
    string $phone,
    array $redirectPageGetParams = []
  ):DraftAgreementData {
    return new DraftAgreementData(
      $product,
      $this->vippsApiConfig->getMerchantRedirectUrl($redirectPageGetParams),
      $this->vippsApiConfig->getMerchantAgreementUrl($redirectPageGetParams),
      $phone,
      $this->mobileDetect->isMobile()
    );
  }

  /**
   * Build the Charge data.
   */
  public function buildCreateChargeData(ProductSubscriptionInterface $product, \DateTime $dateTime):RequestStorageInterface {
    return new CreateChargeData(
      $product,
      // Two days in the future.
      $this->delayManager->getDayAfterTomorrow(),
      intval($this->config->get('charge_retry_days'))
    );
  }

  /**
   * Build the Cancel data.
   */
  public function buildCreateCancelData(ProductSubscriptionInterface $product):RequestStorageInterface {
    return new CancelAgreement($product);
  }

}

==> vipps_recurring_payments-8.x-2.3-beta2.tar.gz: vipps_recurring_payments/src/Factory/RequestStorageFactory.php <==
<?php

declare(strict_types=1);

namespace Drupal\vipps_recurring_payments\Factory;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\vipps_recurring_payments\Form\SettingsForm;
use Drupal\vipps_recurring_payments\RequestStorage\CancelAgreement;
use Drupal\vipps_recurring_payments\RequestStorage\CreateChargeData;
use Drupal\vipps_recurring_payments\RequestStorage\DraftAgreementData;
use Drupal\vipps_recurring_payments\RequestStorage\RequestStorageInterface;
use Drupal\vipps_recurring_payments\Service\DelayManager;
use Drupal\vipps_recurring_payments\Service\VippsApiConfig;
use Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface;
use Detection\MobileDetect;

/**
 * Request Storage Factory.
 */
class RequestStorageFactory {

  /**
   * Vipps Api Config.
   *
   * @var \Drupal\vipps_recurring_payments\Service\VippsApiConfig
   */
  protected $vippsApiConfig;

  /**
   * Configurations.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Delay Manager.
   *
   * @var \Drupal\vipps_recurring_payments\Service\DelayManager
   */
  protected $delayManager;

  /**
   * Mobile detect.
   *
   * @var Mobile_Detect
   */
  private $mobileDetect;

  /**
   * Construct.
   */
  public function __construct(
    VippsApiConfig $vippsApiConfig,
    ConfigFactoryInterface $configFactory,
    DelayManager $delayManager,
    MobileDetect $mobile_detect
  ) {
    $this->vippsApiConfig = $vippsApiConfig;
    $this->config = $configFactory->getEditable(SettingsForm::SETTINGS);
    $this->delayManager = $delayManager;
    $this->mobileDetect = $mobile_detect;
  }

  /**
   * Build the default Agreement data.
   */
  public function buildDefaultDraftAgreement(
    ProductSubscriptionInterface $product,
    string $phone,
    array $redirectPageGetParams = [],
    string $idempotencyKey = ''
  ):DraftAgreementData {
    return new DraftAgreementData(
      $product,
      $this->vippsApiConfig->getMerchantRedirectUrl($redirectPageGetParams),
      $this->vippsApiConfig->getMerchantAgreementUrl($redirectPageGetParams),
      $phone,
      $this->mobileDetect->isMobile(),
      $idempotencyKey
    );
  }

  /**
   * Build the Charge data.
   */
  public function buildCreateChargeData(ProductSubscriptionInterface $product, \DateTime $dateTime):RequestStorageInterface {
    return new CreateChargeData(
      $product,
      // Two days in the future.
      $this->delayManager->getDayAfterTomorrow(),
      intval($this->config->get('charge_retry_days'))
    );
  }

  /**
   * Build the Cancel data.
   */
  public function buildCreateCancelData(ProductSubscriptionInterface $product):RequestStorageInterface {
    return new CancelAgreement($product);
  }

}
